# AmorphSim
This project is just a small project for creating kinematic simulations of amorpohous materials.  In general the kinematics are
correct but the actual results might not be.  There are many factors not considered like disorder in the packing, temperature,
and every cluster is assumed to just have one symmetry. 

Future releases hope to create acutal clusters with different symmetries.
